@@ -1,3 +1,5 @@
-DEFAULT_CONFIG = {
+from typing import Dict
+
+DEFAULT_CONFIG: Dict = {
     "kwargs": {"actor": "actor", "trigger": "trigger", "target": "target"}
 }
